from setuptools import setup

setup(
    name="simple-homework-CS453_123-dictionary",
    author="Emre Derman",
    version="2.0.3",
    packages=["dictionary"],
    install_requires=[
        "requests>=2.23.0",
    ],
    python_requires=">=3.8",

)
